import { GraphQLSchema } from "graphql";
import { Wrapper, GQLElement, Removable, GQLAnyType, KeyValue, SchemaConfig } from "../..";
export declare class Schema<MetaType = KeyValue> extends GQLElement<GraphQLSchema, any, MetaType> {
    protected static _config: SchemaConfig;
    static get config(): SchemaConfig;
    protected _types: GQLAnyType[];
    protected constructor();
    /**
     * Create a new schema
     * @param types The type list to build
     */
    static create(...types: (GQLAnyType | Wrapper)[]): Schema<KeyValue>;
    setConfig(config: SchemaConfig): this;
    /**
     * Set the type list to build
     * @param types The type list to build
     */
    setTypes(...types: (GQLAnyType | Wrapper)[]): this;
    /**
     * Add a type to the list to build
     * @param types The type list to build
     */
    addTypes(...types: (GQLAnyType | Wrapper)[]): this;
    /**
     * Remove some types to the list
     * @param types The type list to remove
     */
    removeTypes(...types: Removable<GQLAnyType>): this;
    /**
     * Build the schema and all the types contained in it
     */
    build(): GraphQLSchema;
}
